@@ -18,13 +18,16 @@
 
 import inspect
 import json
-import pymongo
 from xml.dom.minidom import parseString
-from bson.objectid import ObjectId
 
 class Encoder(json.JSONEncoder):
 	""" class to handle ObjectId on a json document """
 	def default(self,obj):
+		try:
+			from bson.objectid import ObjectId
+		except ImportError:
+			raise Exception("You must have bson installed")
+
 		if isinstance(obj, ObjectId):
 			return unicode(obj)
 		else:
@@ -61,7 +64,7 @@ def convert(class_to_convert,type_to_convert):
 		data = "<"+class_name+">"
 		for v in filter_attr:
 			d = getattr(class_to_convert,v)
-			if type(d).__name__ == "instance":
+			if not check_type(d) and not isinstance(d,list):
 				data += convert(d,type_to_convert)
 			elif isinstance(d,list):
 				data += "<"+v+"s>"
@@ -83,7 +86,7 @@ def convert(class_to_convert,type_to_convert):
 		data = dict()
 		for v in filter_attr:
 			d = getattr(class_to_convert,v)
-			if type(d).__name__ == "instance":
+			if not check_type(d) and not isinstance(d,list):
 				data[v] = convert(d,type_to_convert)
 			elif isinstance(d,list):
 				list_of_element = list()
@@ -93,7 +96,7 @@ def convert(class_to_convert,type_to_convert):
 					elif check_type(a):
 						list_of_element.append(a)
 
-					data[v+"s"] = list_of_element
+				data[v+"s"] = list_of_element
 			else:
 				data[v] = d
 
@@ -174,6 +177,11 @@ def convertMongo2XML(root_element, data):
 		returns:
 			xml.dom.minidom.Document	
 	"""
+	try:
+		import pymongo
+	except ImportError:
+		raise Exception("You must install pymongo")
+
 	if isinstance(data, pymongo.cursor.Cursor):
 		data_list = list(data)
 		return convertJSON2XML(root_element,data_list)
@@ -189,6 +197,11 @@ def convertMongo2JSON(data):
 		returns:
 			json (python dictionary)
 	"""
+	try:
+		import pymongo
+	except ImportError:
+		raise Exception("You must install pymongo")
+
 	if isinstance(data, pymongo.cursor.Cursor):
 		l = list()
 		for d in list(data):
